<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ext="java:lu.bourse.api.deposant.action.xsl.XslManager"
	xmlns:ns="http://www.bourse.lu/rap/O42"
	xmlns:fnbourse="http://www.bcl.lu/2006/bcl-xpath-functions"
	exclude-result-prefixes="ext fnbourse"
	version="2.0">

	<xsl:output method="xml" indent="yes" />
	
	<xsl:param name="spaceParam" />

	<!--  -->
	<!-- Début Partie sur les Tests de Contrôles liées aux fichiers Déposés -->
	<!--  -->

	<xsl:template name="obtenirDateFormatee">
		<xsl:param name="dateEntree" />
		<xsl:param name="formatEntree" />
		<xsl:param name="formatSortie" />
		<xsl:variable name="timeVide" select="'00:00:00'" />

		<xsl:choose>
			<xsl:when test="$formatEntree='ddmmyyyy'">
				<xsl:choose>
					<xsl:when test="$formatSortie='date'">
						<xsl:value-of
							select="concat(substring($dateEntree, 5, 4), '-', substring($dateEntree, 3, 2), '-', substring($dateEntree, 1, 2))" />
					</xsl:when>
					<xsl:when test="$formatSortie='dateTime'">
						<xsl:value-of
							select="concat(substring($dateEntree, 5, 4), '-', substring($dateEntree, 3, 2), '-', substring($dateEntree, 1, 2), 'T', $timeVide)" />
					</xsl:when>
				</xsl:choose>
			</xsl:when>

			<xsl:when test="$formatEntree='yyyymmdd_hhmmss'">
				<xsl:choose>
					<xsl:when test="$formatSortie='date'">
						<xsl:value-of
							select="concat(substring($dateEntree, 1, 4), '-', substring($dateEntree, 5, 2), '-', substring($dateEntree, 7, 2))" />
					</xsl:when>
					<xsl:when test="$formatSortie='dateTime'">
						<xsl:value-of
							select="concat(substring($dateEntree, 1, 4), '-', substring($dateEntree, 5, 2), '-', substring($dateEntree, 7, 2), 'T', substring($dateEntree, 10, 2), ':', substring($dateEntree, 12, 2), ':', substring($dateEntree, 14, 2))" />
					</xsl:when>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="boucleTest" match="/file">

		<xsl:param name="iteration" select="1" />

		<xsl:if test="count(row) > $iteration ">
			<xsl:call-template name="boucleTest">
				<xsl:with-param name="iteration"
					select="$iteration + 1" />
			</xsl:call-template>
		</xsl:if>

		<!--  -->
		<!-- Fin Partie sur les Tests de Contrôles liés aux fichiers Déposés -->
		<!--  -->

		<!--  -->
		<!--  On n'effectue la transformation em Message Pivot seulement si l'ensemble des Tests ont été réalisés avec succès -->
		<!--  -->
		<xsl:if test="$iteration = count(row)">
			<ns:MsgInO42>
				<ns:Vers SchemaVers="1.0">
					<xsl:variable name="numVersXSD"
						select="ext:recupNumVersXSDFile($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$numVersXSD" />
				</ns:Vers>
				<xsl:call-template name="ELT-TECH" />
				<ns:SeqInO42>
					<ns:Conc1>
						<xsl:call-template name="SEQUENCE-IN-O42" />
					</ns:Conc1>
				</ns:SeqInO42>
			</ns:MsgInO42>
		</xsl:if>
	</xsl:template>


	<xsl:template name="replace-string">
	  <xsl:param name="str" />
		<xsl:param name="strToReplace" />
		<xsl:param name="newStr" />
		<xsl:choose>
  		<xsl:when test="contains($str,$strToReplace)">
        <xsl:value-of select="concat(substring-before($str,$strToReplace),$newStr)"/>
        <xsl:call-template name="replace-string"> 
          <xsl:with-param name="str" select="substring-after($str,$strToReplace)" /> 
          <xsl:with-param name="strToReplace" select="$strToReplace" /> 
          <xsl:with-param name="newStr" select="$newStr" /> 
        </xsl:call-template> 
      </xsl:when> 
      <xsl:otherwise>
        <xsl:value-of select="$str"/>
      </xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template name="ELT-TECH">
		<ns:other>
			<ns:EltTech>
				<ns:ListeDev>
					<xsl:value-of select="ext:getListeDevises()" />
				</ns:ListeDev>
				<ns:CdLang>
					<xsl:value-of select="ext:getLang()" />
				</ns:CdLang>
				<ns:UrlCombo>
					<xsl:value-of select="ext:recupDonnee('WS_URL_COMBO', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlCombo>
				<ns:UrlDownload>
					<xsl:value-of select="ext:recupDonnee('WS_URL_DOWNLOAD', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlDownload>
				<ns:UrlCmun>
					<xsl:value-of select="ext:recupDonnee('WS_URL_COMMUN', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlCmun>
				<ns:CdIdentAcCssf>
					<xsl:value-of select="ext:obtenirCdAcCssf($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:CdIdentAcCssf>
				<ns:CdIdentAcBcl>
					<xsl:value-of select="ext:obtenirCdAc($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:CdIdentAcBcl>
				<ns:DtCre>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtCre>
				<ns:DtEnvoi>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtEnvoi>
				<ns:DtValidat>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtValidat>
				<ns:NumMess>
					<xsl:variable name="numMess"
						select="ext:recupNumeroMessage($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$numMess" />
				</ns:NumMess>
				<ns:MotPasAc>
					<xsl:variable name="pwdAc"
						select="ext:obtenirPwdAc($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$pwdAc" />
				</ns:MotPasAc>
				<ns:CdAuthent>
					<xsl:variable name="cdAuth"
						select="ext:obtenirCodeAuth($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$cdAuth" />
				</ns:CdAuthent>
				<ns:CdOpe>
					<xsl:value-of
						select="row[@id='filtre1801']/col[@id=3]" />
				</ns:CdOpe>
				<ns:Sess>
					<xsl:value-of select="''" />
				</ns:Sess>
				<ns:IdTypeDoc>
					<xsl:variable name="typeDoc"
						select="ext:recupDonnee('TYPE_DOC', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$typeDoc" />
				</ns:IdTypeDoc>
			</ns:EltTech>
		</ns:other>

	</xsl:template>

	<xsl:template name="SEQUENCE-IN-O42">
		<xsl:call-template name="SEGMENT-CONTEXT" />
		<xsl:call-template name="SEGMENT-P100" />
		<xsl:call-template name="SEGMENT-P200" />
	</xsl:template>

	<xsl:template name="SEGMENT-CONTEXT">
		<ns:Context>
			<xsl:call-template name="CONTEXT-STRUCTJUROPC" />
			<xsl:call-template name="CONTEXT-TECH" />
			<xsl:call-template name="CONTEXT-TECHCONTACT" />
			<xsl:call-template name="CONTEXT-INSTRCOMPART" />
			<xsl:call-template name="CONTEXT-INSTRFONDS" />
			<xsl:call-template name="CONTEXT-DEV" />
			<xsl:call-template name="CONTEXT-COLLCOMPARTRAPO42" />
		</ns:Context>
	</xsl:template>

	<xsl:template name="CONTEXT-STRUCTJUROPC">
		<ns:StructJurOpc>
			<ns:CdStructJurOpc>
				<xsl:variable name="idStructJurOpc"
					select="ext:recupDonnee('IDSTRUCTJUROPC', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$idStructJurOpc" />
			</ns:CdStructJurOpc>
		</ns:StructJurOpc>
	</xsl:template>

	<xsl:template name="CONTEXT-TECH">
		<ns:Tech>
			<ns:Adr>
				<xsl:variable name="adresse1"
					select="ext:recupDonnee('ADDRESSE1', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$adresse1" />
				<xsl:variable name="adresse2"
					select="ext:recupDonnee('ADDRESSE2', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$adresse2" />
			</ns:Adr>
			<ns:CdPostal>
				<xsl:variable name="cdpostal"
					select="ext:recupDonnee('CDPOSTAL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$cdpostal" />
			</ns:CdPostal>
			<ns:Ville>
				<xsl:variable name="ville"
					select="ext:recupDonnee('VILLE', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$ville" />
			</ns:Ville>
			<ns:Pays>
				<xsl:variable name="pays"
					select="ext:recupDonnee('IDPAYS', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$pays" />
			</ns:Pays>
		</ns:Tech>
	</xsl:template>


	<xsl:template name="CONTEXT-TECHCONTACT">
		<ns:TechContact>
			<ns:Titre>
				<xsl:value-of select="''" />
			</ns:Titre>
			<ns:Nom>
				<xsl:variable name="nomUtil"
					select="ext:recupDonnee('NOMUTIL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$nomUtil" />
			</ns:Nom>
			<ns:Prenom>
				<xsl:variable name="prenomUtil"
					select="ext:recupDonnee('PRENOMUTIL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$prenomUtil" />
			</ns:Prenom>
			<ns:Tel>
				<xsl:variable name="tel"
					select="ext:recupDonnee('TEL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$tel" />
			</ns:Tel>
		</ns:TechContact>
	</xsl:template>

	<xsl:template name="CONTEXT-COLLCOMPARTRAPO42">
		<ns:CollCompartRapO42>
			<ns:CdCssfOpc>
				<xsl:value-of
					select="normalize-space(row[@id='filtre1801']/col[@id=4])" />
			</ns:CdCssfOpc>
			<ns:CdCssfCompart>
				<xsl:value-of
					select="normalize-space(row[@id='filtre1801']/col[@id=5])" />
			</ns:CdCssfCompart>
			<ns:CdAacOpc>
				<xsl:value-of select="row[@id='filtre1801']/col[@id=6]" />
			</ns:CdAacOpc>
			<ns:CdAacCompart>
				<xsl:value-of select="row[@id='filtre1801']/col[@id=7]" />
			</ns:CdAacCompart>
			<ns:DtDebRap>
				<xsl:variable name="dtDebRap"
					select="row[@id='filtre1801']/col[@id=8]" />
				<xsl:call-template name="obtenirDateFormatee">
					<xsl:with-param name="dateEntree"
						select="ext:obtenirDate($dtDebRap)" />
					<xsl:with-param name="formatEntree"
						select="'ddmmyyyy'" />
					<xsl:with-param name="formatSortie"
						select="'date'" />
				</xsl:call-template>
			</ns:DtDebRap>
			<ns:DtFinRap>
				<xsl:variable name="dtFinRap"
					select="row[@id='filtre1801']/col[@id=9]" />
				<xsl:call-template name="obtenirDateFormatee">
					<xsl:with-param name="dateEntree"
						select="ext:obtenirDate($dtFinRap)" />
					<xsl:with-param name="formatEntree"
						select="'ddmmyyyy'" />
					<xsl:with-param name="formatSortie"
						select="'date'" />
				</xsl:call-template>
			</ns:DtFinRap>
			<ns:TxChge>
				<xsl:value-of select="format-number(row[@id='filtre1801']/col[@id=11] div 100000, '#.#####')" />
			</ns:TxChge>
		</ns:CollCompartRapO42>
	</xsl:template>

	<xsl:template name="CONTEXT-INSTRCOMPART">
		<ns:InstrCompart>
			<ns:LibAbrInstr>
				<xsl:variable name="libInstrCompart"
					select="ext:obtenirContextForm(row[@id='filtre1801']/ficOri, row[@id='filtre1801']/ligneOri,'COMPART', row[@id='filtre1801']/col[@id=4], row[@id='filtre1801']/col[@id=5], row[@id='filtre1801']/col[@id=6], row[@id='filtre1801']/col[@id=7], $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:call-template name="replace-string">
				  <xsl:with-param name="str"
						select="$libInstrCompart" />
					<xsl:with-param name="strToReplace"
						select="'&#128;'" />
					<xsl:with-param name="newStr"
						select="'&#8364;'" />
				</xsl:call-template>
			</ns:LibAbrInstr>
		</ns:InstrCompart>
	</xsl:template>

	<xsl:template name="CONTEXT-INSTRFONDS">
		<ns:InstrFonds>
			<ns:LibAbrInstr>
				<xsl:variable name="libInstrFonds"
					select="ext:obtenirContextForm(row[@id='filtre1801']/ficOri, row[@id='filtre1801']/ligneOri,'FONDS', row[@id='filtre1801']/col[@id=4], row[@id='filtre1801']/col[@id=5], row[@id='filtre1801']/col[@id=6], row[@id='filtre1801']/col[@id=7], $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:call-template name="replace-string">
				  <xsl:with-param name="str"
						select="$libInstrFonds" />
					<xsl:with-param name="strToReplace"
						select="'&#128;'" />
					<xsl:with-param name="newStr"
						select="'&#8364;'" />
				</xsl:call-template>
			</ns:LibAbrInstr>
		</ns:InstrFonds>
	</xsl:template>

	<xsl:template name="CONTEXT-DEV">
		<ns:Dev>
			<ns:CdDevIso>
				<xsl:value-of
					select="row[@id='filtre1801']/col[@id=10]" />
			</ns:CdDevIso>
		</ns:Dev>
	</xsl:template>



	<xsl:template name="SEGMENT-P100">
		<ns:P100>
			<ns:L100>
				<ns:Mt>
					<xsl:value-of
						select="row[@id='filtre1801']/col[@id=12]" />
				</ns:Mt>
			</ns:L100>
			<ns:L101>
				<ns:Mt>
					<xsl:value-of
						select="row[@id='filtre1801']/col[@id=13]" />
				</ns:Mt>
			</ns:L101>
			<ns:L102>
				<ns:Mt>
					<xsl:value-of
						select="row[@id='filtre1801']/col[@id=14]" />
				</ns:Mt>
			</ns:L102>
			<ns:L103>
				<ns:Mt>
					<xsl:value-of
						select="row[@id='filtre1801']/col[@id=15]" />
				</ns:Mt>
			</ns:L103>
		</ns:P100>
	</xsl:template>

	<xsl:template name="SEGMENT-P200">
		<ns:P200>
			<ns:L201>
				<ns:Mt>
					<xsl:value-of
						select="row[@id='filtre1801']/col[@id=16]" />
				</ns:Mt>
			</ns:L201>
			<ns:L202>
				<ns:Mt>
					<xsl:value-of
						select="row[@id='filtre1801']/col[@id=17]" />
				</ns:Mt>
			</ns:L202>
		</ns:P200>
	</xsl:template>
</xsl:stylesheet>