<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ext="java:lu.bourse.api.deposant.action.xsl.XslManager"
	xmlns:ns="http://www.bourse.lu/rap/S212"
	xmlns:fnbourse="http://www.bcl.lu/2006/bcl-xpath-functions"
	exclude-result-prefixes="ext fnbourse"
	version="2.0">

	<xsl:output method="xml" indent="yes" />
	
	<xsl:param name="spaceParam" />
	<xsl:param name="mappingParam" />
	
	<!--  -->
	<!-- Début Partie sur les Tests de Contrôles liées aux fichiers Déposés -->
	<!--  -->

	<xsl:template name="obtenirDateFormatee">
		<xsl:param name="dateEntree" />
		<xsl:param name="formatEntree" />
		<xsl:param name="formatSortie" />
		<xsl:variable name="timeVide" select="'00:00:00'" />

		<xsl:choose>
			<xsl:when test="$formatEntree='ddmmyyyy'">
				<xsl:choose>
					<xsl:when test="$formatSortie='date'">
						<xsl:value-of
							select="concat(substring($dateEntree, 5, 4), '-', substring($dateEntree, 3, 2), '-', substring($dateEntree, 1, 2))" />
					</xsl:when>
					<xsl:when test="$formatSortie='dateTime'">
						<xsl:value-of
							select="concat(substring($dateEntree, 5, 4), '-', substring($dateEntree, 3, 2), '-', substring($dateEntree, 1, 2), 'T', $timeVide)" />
					</xsl:when>
				</xsl:choose>
			</xsl:when>

			<xsl:when test="$formatEntree='yyyymmdd_hhmmss'">
				<xsl:choose>
					<xsl:when test="$formatSortie='date'">
						<xsl:value-of
							select="concat(substring($dateEntree, 1, 4), '-', substring($dateEntree, 5, 2), '-', substring($dateEntree, 7, 2))" />
					</xsl:when>
					<xsl:when test="$formatSortie='dateTime'">
						<xsl:value-of
							select="concat(substring($dateEntree, 1, 4), '-', substring($dateEntree, 5, 2), '-', substring($dateEntree, 7, 2), 'T', substring($dateEntree, 10, 2), ':', substring($dateEntree, 12, 2), ':', substring($dateEntree, 14, 2))" />
					</xsl:when>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="boucleTest" match="/file">

		<xsl:param name="iteration" select="1" />


		<xsl:if test="count(row) > $iteration ">
			<xsl:call-template name="boucleTest">
				<xsl:with-param name="iteration"
					select="$iteration + 1" />
			</xsl:call-template>
		</xsl:if>

		<!--  -->
		<!-- Fin Partie sur les Tests de Contrôles liés aux fichiers Déposés -->
		<!--  -->

		<!--  -->
		<!--  On n'effectue la transformation em Message Pivot seulement si l'ensemble des Tests ont été réalisés avec succès -->
		<!--  -->
		<xsl:if test="$iteration = count(row)">
			<ns:MsgInS212>
				<ns:Vers SchemaVers="1.0">
					<xsl:variable name="numVersXSD"
						select="ext:recupNumVersXSDFile($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$numVersXSD" />
				</ns:Vers>
				<xsl:call-template name="ELT-TECH" />
				<ns:SeqInS212>
					<ns:Conc1>
						<xsl:call-template name="SEQUENCE-IN-S212" />
					</ns:Conc1>
				</ns:SeqInS212>
			</ns:MsgInS212>
		</xsl:if>
	</xsl:template>

	<xsl:template name="replace-string">
	  <xsl:param name="str" />
		<xsl:param name="strToReplace" />
		<xsl:param name="newStr" />
		<xsl:choose>
  		<xsl:when test="contains($str,$strToReplace)">
        <xsl:value-of select="concat(substring-before($str,$strToReplace),$newStr)"/>
        <xsl:call-template name="replace-string"> 
          <xsl:with-param name="str" select="substring-after($str,$strToReplace)" /> 
          <xsl:with-param name="strToReplace" select="$strToReplace" /> 
          <xsl:with-param name="newStr" select="$newStr" /> 
        </xsl:call-template> 
      </xsl:when> 
      <xsl:otherwise>
        <xsl:value-of select="$str"/>
      </xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="ELT-TECH">
		<ns:other>
			<ns:EltTech>
				<ns:ListeDev>
					<xsl:value-of select="ext:getListeDevises()" />
				</ns:ListeDev>
				<ns:CdLang>
					<xsl:value-of select="ext:getLang()" />
				</ns:CdLang>
				<ns:UrlCombo>
					<xsl:value-of select="ext:recupDonnee('WS_URL_COMBO', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlCombo>
				<ns:UrlDownload>
					<xsl:value-of select="ext:recupDonnee('WS_URL_DOWNLOAD', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlDownload>
				<ns:UrlCmun>
					<xsl:value-of select="ext:recupDonnee('WS_URL_COMMUN', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlCmun>
				<ns:CdIdentAcCssf>
					<xsl:value-of select="ext:obtenirCdAcCssf($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:CdIdentAcCssf>
				<ns:CdIdentAcBcl>
					<xsl:value-of select="ext:obtenirCdAc($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:CdIdentAcBcl>	
				<ns:DtCre>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtCre>
				<ns:DtEnvoi>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtEnvoi>
				<ns:DtValidat>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtValidat>
				<ns:NumMess>
					<xsl:variable name="numMess"
						select="ext:recupNumeroMessage($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$numMess" />
				</ns:NumMess>
				<ns:MotPasAc>
					<xsl:variable name="pwdAc"
						select="ext:obtenirPwdAc($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$pwdAc" />
				</ns:MotPasAc>
				<ns:CdAuthent>
					<xsl:variable name="cdAuth"
						select="ext:obtenirCodeAuth($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$cdAuth" />
				</ns:CdAuthent>
				<ns:CdOpe>
					<xsl:value-of
						select="row[@id='filtre2601']/col[@id=3]" />
				</ns:CdOpe>
				<ns:Sess>
					<xsl:value-of select="''" />
				</ns:Sess>
				<ns:IdTypeDoc>
					<xsl:variable name="typeDoc"
						select="ext:recupDonnee('TYPE_DOC', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$typeDoc" />
				</ns:IdTypeDoc>
			</ns:EltTech>
		</ns:other>
	</xsl:template>

	<xsl:template name="SEQUENCE-IN-S212">
		<xsl:call-template name="SEGMENT-CONTEXT" />
		<xsl:call-template name="SEGMENT-ACTIF" />
	</xsl:template>

	<xsl:template name="SEGMENT-CONTEXT">
		<ns:Context>
			<xsl:call-template name="CONTEXT-STRUCTJUROPC" />
			<xsl:call-template name="CONTEXT-TECH" />
			<xsl:call-template name="CONTEXT-TECHCONTACT" />
			<xsl:call-template name="CONTEXT-CODIFINSTRFONDS" />
			<xsl:call-template name="CONTEXT-INSTRFONDS" />
			<xsl:call-template name="CONTEXT-CDINTERNEFONDS" />
			<xsl:call-template name="CONTEXT-CODIFINSTRCOMPART" />
			<xsl:call-template name="CONTEXT-INSTRCOMPART" />
			<xsl:call-template name="CONTEXT-CDINTERNECOMPART" />
			<xsl:call-template name="CONTEXT-DEV" />
			<xsl:call-template name="CONTEXT-CONTEXTRAPMENSS2121" />
		</ns:Context>
	</xsl:template>

	<xsl:template name="CONTEXT-STRUCTJUROPC">
		<ns:StructJurOpc>
			<ns:CdStructJurOpc>
				<xsl:variable name="idStructJurOpc"
					select="ext:recupDonnee('IDSTRUCTJUROPC', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$idStructJurOpc" />
			</ns:CdStructJurOpc>
		</ns:StructJurOpc>
	</xsl:template>

	<xsl:template name="CONTEXT-TECH">
		<ns:Tech>
			<ns:Adr>
				<xsl:variable name="adresse1"
					select="ext:recupDonnee('ADDRESSE1', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$adresse1" />
				<xsl:variable name="adresse2"
					select="ext:recupDonnee('ADDRESSE2', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$adresse2" />
			</ns:Adr>
			<ns:CdPostal>
				<xsl:variable name="cdpostal"
					select="ext:recupDonnee('CDPOSTAL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$cdpostal" />
			</ns:CdPostal>
			<ns:Ville>
				<xsl:variable name="ville"
					select="ext:recupDonnee('VILLE', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$ville" />
			</ns:Ville>
			<ns:Pays>
				<xsl:variable name="pays"
					select="ext:recupDonnee('IDPAYS', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$pays" />
			</ns:Pays>
		</ns:Tech>
	</xsl:template>


	<xsl:template name="CONTEXT-TECHCONTACT">
		<ns:TechContact>
			<ns:Titre>
				<xsl:value-of select="''" />
			</ns:Titre>
			<ns:Nom>
				<xsl:variable name="nomUtil"
					select="ext:recupDonnee('NOMUTIL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$nomUtil" />
			</ns:Nom>
			<ns:Prenom>
				<xsl:variable name="prenomUtil"
					select="ext:recupDonnee('PRENOMUTIL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$prenomUtil" />
			</ns:Prenom>
			<ns:Tel>
				<xsl:variable name="tel"
					select="ext:recupDonnee('TEL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$tel" />
			</ns:Tel>
		</ns:TechContact>
	</xsl:template>

	<xsl:template name="CONTEXT-CODIFINSTRFONDS">
		<ns:CodifInstrFonds>
			<ns:CodifInstr>
				<xsl:value-of select="row[@id='filtre2601']/col[@id=4]" />
			</ns:CodifInstr>
		</ns:CodifInstrFonds>
	</xsl:template>

	<xsl:template name="CONTEXT-INSTRFONDS">
		<ns:InstrFonds>
			<ns:LibAbrInstr>
				<xsl:variable name="libInstrFonds"
					select="ext:obtenirContextForm(row[@id='filtre2601']/ficOri, row[@id='filtre2601']/ligneOri,'FONDS', row[@id='filtre2601']/col[@id=4], row[@id='filtre2601']/col[@id=5], row[@id='filtre2601']/col[@id=6], row[@id='filtre2601']/col[@id=7], $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:call-template name="replace-string">
				  <xsl:with-param name="str"
						select="$libInstrFonds" />
					<xsl:with-param name="strToReplace"
						select="'&#128;'" /><!-- On remplace le caractere euro par un encoding euro correct pour l'afficher correctement dans les pdf'-->
					<xsl:with-param name="newStr"
						select="'&#8364;'" />
				</xsl:call-template>
			</ns:LibAbrInstr>
		</ns:InstrFonds>
	</xsl:template>

	<xsl:template name="CONTEXT-CDINTERNEFONDS">
		<ns:CdInterneFonds>
			<xsl:value-of select="row[@id='filtre2601']/col[@id=6]" />
		</ns:CdInterneFonds>
	</xsl:template>

	<xsl:template name="CONTEXT-CODIFINSTRCOMPART">
		<ns:CodifInstrCompart>
			<ns:CodifInstr>
				<xsl:value-of select="row[@id='filtre2601']/col[@id=5]" />
			</ns:CodifInstr>
		</ns:CodifInstrCompart>
	</xsl:template>

	<xsl:template name="CONTEXT-INSTRCOMPART">
		<ns:InstrCompart>
			<ns:LibAbrInstr>
				<xsl:variable name="libInstrCompart"
					select="ext:obtenirContextForm(row[@id='filtre2601']/ficOri, row[@id='filtre2601']/ligneOri,'COMPART', row[@id='filtre2601']/col[@id=4], row[@id='filtre2601']/col[@id=5], row[@id='filtre2601']/col[@id=6], row[@id='filtre2601']/col[@id=7], $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:call-template name="replace-string">
				  <xsl:with-param name="str"
						select="$libInstrCompart" />
					<xsl:with-param name="strToReplace"
						select="'&#128;'" /><!-- On remplace le caractere euro par un encoding euro correct pour l'afficher correctement dans les pdf'-->
					<xsl:with-param name="newStr"
						select="'&#8364;'" />
				</xsl:call-template>
			</ns:LibAbrInstr>
		</ns:InstrCompart>
	</xsl:template>

	<xsl:template name="CONTEXT-CDINTERNECOMPART">
		<ns:CdInterneCompart>
			<xsl:value-of select="row[@id='filtre2601']/col[@id=7]" />
		</ns:CdInterneCompart>
	</xsl:template>

	<xsl:template name="CONTEXT-DEV">
		<ns:Dev>
			<ns:CdDevIso>
				<xsl:value-of
					select="row[@id='filtre2601']/col[@id=10]" />
			</ns:CdDevIso>
		</ns:Dev>
	</xsl:template>

	<xsl:template name="CONTEXT-CONTEXTRAPMENSS2121">
		<ns:ContextRapMensS212>
			<ns:DtDebRap>
				<xsl:variable name="dtDebRap"
					select="row[@id='filtre2601']/col[@id=8]" />
				<xsl:call-template name="obtenirDateFormatee">
					<xsl:with-param name="dateEntree"
						select="ext:obtenirDate($dtDebRap)" />
					<xsl:with-param name="formatEntree"
						select="'ddmmyyyy'" />
					<xsl:with-param name="formatSortie"
						select="'dateTime'" />
				</xsl:call-template>
			</ns:DtDebRap>
			<ns:DtFinRap>
				<xsl:variable name="dtFinRap"
					select="row[@id='filtre2601']/col[@id=9]" />
				<xsl:call-template name="obtenirDateFormatee">
					<xsl:with-param name="dateEntree"
						select="ext:obtenirDate($dtFinRap)" />
					<xsl:with-param name="formatEntree"
						select="'ddmmyyyy'" />
					<xsl:with-param name="formatSortie"
						select="'dateTime'" />
				</xsl:call-template>
			</ns:DtFinRap>
			<ns:TxChgeIml>
				<xsl:value-of select="format-number(row[@id='filtre2601']/col[@id=11] div 100000, '#.#####')" />
			</ns:TxChgeIml>
		</ns:ContextRapMensS212>
	</xsl:template>

	<xsl:template name="decoupe-codeLigneEdifact">
		<xsl:param name="ligne" />
		<xsl:value-of
			select="concat(substring($ligne, 2,1), '-',substring($ligne, 3,3), '-', substring($ligne, 6,2), '-', substring($ligne, 8,3), '-',  substring($ligne, 11,5))" />
	</xsl:template>

	<xsl:template name="obtenirLigneUnitaire">
		<xsl:param name="ligne" />
		<xsl:param name="newline" />
		<xsl:if test="'$newline'='$ligne'">
			<xsl:value-of select="$ligne" />
		</xsl:if>
	</xsl:template>

	<xsl:template name="obtenirPays">
		<xsl:param name="ligne" />
		<ns:Pays>
			<xsl:value-of select="substring($ligne, 7, 2)"
				xmlns:spaceParam="java:lu.bourse.services.workflow.Space"
				xmlns:mappingParam="java:lu.bourse.api.deposant.mapping.MappingHelper"/>
		</ns:Pays>
	</xsl:template>

	<xsl:template name="obtenirDevise">
		<xsl:param name="ligne" />
		<ns:Dev>
			<xsl:value-of select="substring($ligne, 10, 3)" />
		</ns:Dev>
	</xsl:template>

	<xsl:template name="obtenirSectEco">
		<xsl:param name="ligne" />
		<ns:SectEco>
			<xsl:value-of select="substring($ligne, 14, 5)" />	
		</ns:SectEco>
	</xsl:template>

	<xsl:template name="obtenirPeriode">
		<xsl:param name="ligne" />
		<xsl:choose>
			<xsl:when test="@id='filtre2602'">
				<xsl:if test="col[@id=11]='BRA'">
					<ns:Inf3m>
						<xsl:value-of select="col[@id=12]" />
					</ns:Inf3m>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRB'">
					<ns:Inf1>
						<xsl:value-of select="col[@id=12]" />
					</ns:Inf1>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRC'">
					<ns:Inf1>
						<xsl:value-of select="col[@id=12]" />
					</ns:Inf1>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRG'">
					<ns:Inf2>
						<xsl:value-of select="col[@id=12]" />
					</ns:Inf2>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRH'">
					<ns:Inf5>
						<xsl:value-of select="col[@id=12]" />
					</ns:Inf5>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRJ'">
					<ns:Sup2>
						<xsl:value-of select="col[@id=12]" />
					</ns:Sup2>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRK'">
					<ns:Sup5>
						<xsl:value-of select="col[@id=12]" />
					</ns:Sup5>
				</xsl:if>
				<xsl:if test="col[@id=11]='BRX'">
					<ns:Nv>
						<xsl:value-of select="col[@id=12]" />
					</ns:Nv>
				</xsl:if>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="obtenirContenuBalise">
		<xsl:param name="ligne" />
		<xsl:variable name="valueLine"
			select="ext:initValueLine($spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
		<xsl:if test="$valueLine='true'"></xsl:if>

		<xsl:variable name="firstPass">
			<xsl:call-template name="decoupe-codeLigneEdifact">
				<xsl:with-param name="ligne" select="$ligne" />
			</xsl:call-template>
		</xsl:variable>

		<xsl:for-each select="row">
			<xsl:variable name="resultDecoupe">
				<xsl:call-template name="decoupe-codeLigneEdifact">
					<xsl:with-param name="ligne" select="$ligne" />
				</xsl:call-template>
			</xsl:variable>

			<xsl:if test="col[@id=10]=$resultDecoupe">
				<xsl:variable name="valueLine2"
					select="ext:setHasValueLine($spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:if test="$valueLine2='true'"></xsl:if>

				<xsl:call-template name="obtenirLigneUnitaire">
					<xsl:with-param name="newline" select="$firstPass" />
					<xsl:with-param name="ligne"
						select="$resultDecoupe" />
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>

		<xsl:variable name="valueLine3"
			select="ext:obtenirValueLine($spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
		<xsl:if test="$valueLine3='yes'">
			<xsl:variable name="ligneUnitaire" select="$firstPass" />

			<xsl:call-template name="obtenirPays">
				<xsl:with-param name="ligne" select="$ligneUnitaire" />
			</xsl:call-template>

			<xsl:call-template name="obtenirDevise">
				<xsl:with-param name="ligne" select="$ligneUnitaire" />
			</xsl:call-template>

			<xsl:call-template name="obtenirSectEco">
				<xsl:with-param name="ligne" select="$ligneUnitaire" />
			</xsl:call-template>

		</xsl:if>

		<xsl:if test="$valueLine3!='yes'">
			<ns:Pays></ns:Pays>
			<ns:Dev></ns:Dev>
			<ns:SectEco></ns:SectEco>
		</xsl:if>

		<xsl:if test="substring($ligne, 2,1)='1'">
			<xsl:for-each select="row">
				<xsl:variable name="resultDecoupe">
					<xsl:call-template
						name="decoupe-codeLigneEdifact">
						<xsl:with-param name="ligne" select="$ligne" />
					</xsl:call-template>
				</xsl:variable>

				<xsl:if test="col[@id=10]=$resultDecoupe">
					<xsl:call-template name="obtenirPeriode">
						<xsl:with-param name="ligne"
							select="$resultDecoupe" />
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="substring($ligne, 2,1)='2'">
			<xsl:for-each select="row">
				<xsl:variable name="resultDecoupe">
					<xsl:call-template
						name="decoupe-codeLigneEdifact">
						<xsl:with-param name="ligne" select="$ligne" />
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="col[@id=10]=$resultDecoupe">
					<xsl:call-template name="obtenirPeriode">
						<xsl:with-param name="ligne"
							select="$resultDecoupe" />
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>


	<xsl:template name="SEGMENT-ACTIF">
		<ns:Actif>
			<xsl:call-template name="ACTIF-A020" />
			<xsl:call-template name="ACTIF-A030" />
			<xsl:call-template name="ACTIF-A050" />
		</ns:Actif>
	</xsl:template>

	<xsl:template name="ACTIF-A020">
		<ns:A020>
			<ns:Rubr>020</ns:Rubr>
			<ns:L1020LUXX110000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUXX110000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUXX110000>
			<ns:L1020LUXX131000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUXX131000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUXX131000>
			<ns:L1020LUXX132100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUXX132100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUXX132100>
			<ns:L1020LUXX132200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUXX132200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUXX132200>
			<ns:L1020LUXX132300>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020LUXX132300'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020LUXX132300>
			<ns:L1020X3XX110000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3XX110000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3XX110000>
			<ns:L1020X3XX131000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3XX131000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3XX131000>
			<ns:L1020X3XX132100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3XX132100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3XX132100>
			<ns:L1020X3XX132200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3XX132200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3XX132200>
			<ns:L1020X3XX132300>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X3XX132300'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X3XX132300>
			<ns:L1020X4XX111000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4XX111000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4XX111000>
			<ns:L1020X4XX130000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4XX130000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4XX130000>
			<ns:L1020X4XX140000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1020X4XX140000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1020X4XX140000>
		</ns:A020>
	</xsl:template>

	<xsl:template name="ACTIF-A030">
		<ns:A030>
			<ns:Rubr>030</ns:Rubr>
			<ns:L1030LUXX110000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX110000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX110000>
			<ns:L1030LUXX131000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX131000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX131000>
			<ns:L1030LUXX132100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX132100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX132100>
			<ns:L1030LUXX132200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX132200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX132200>
			<ns:L1030LUXX132300>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX132300'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX132300>
			<ns:L1030LUXX141100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX141100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX141100>
			<ns:L1030LUXX141200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX141200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX141200>
			<ns:L1030LUXX142100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX142100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX142100>
			<ns:L1030LUXX142200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030LUXX142200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030LUXX142200>
			<ns:L1030X3XX110000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX110000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX110000>
			<ns:L1030X3XX131000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX131000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX131000>
			<ns:L1030X3XX132100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX132100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX132100>
			<ns:L1030X3XX132200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX132200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX132200>
			<ns:L1030X3XX132300>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX132300'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX132300>
			<ns:L1030X3XX141100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX141100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX141100>
			<ns:L1030X3XX141200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX141200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX141200>
			<ns:L1030X3XX142100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX142100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX142100>
			<ns:L1030X3XX142200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X3XX142200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X3XX142200>
			<ns:L1030X4XX111000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4XX111000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4XX111000>
			<ns:L1030X4XX130000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4XX130000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4XX130000>
			<ns:L1030X4XX140000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1030X4XX140000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1030X4XX140000>
		</ns:A030>
	</xsl:template>

	<xsl:template name="ACTIF-A050">
		<ns:A050>
			<ns:Rubr>050</ns:Rubr>
			<ns:L1050LUXX110000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050LUXX110000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050LUXX110000>
			<ns:L1050LUXX141100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050LUXX141100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050LUXX141100>
			<ns:L1050LUXX141200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050LUXX141200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050LUXX141200>
			<ns:L1050LUXX142100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050LUXX142100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050LUXX142100>
			<ns:L1050LUXX142200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050LUXX142200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050LUXX142200>
			<ns:L1050X3XX110000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050X3XX110000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050X3XX110000>
			<ns:L1050X3XX141100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050X3XX141100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050X3XX141100>
			<ns:L1050X3XX141200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050X3XX141200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050X3XX141200>
			<ns:L1050X3XX142100>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050X3XX142100'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050X3XX142100>
			<ns:L1050X3XX142200>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050X3XX142200'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050X3XX142200>
			<ns:L1050X4XX111000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050X4XX111000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050X4XX111000>
			<ns:L1050X4XX140000>
				<ns:LigneA>
					<xsl:call-template name="obtenirContenuBalise">
						<xsl:with-param name="ligne"
							select="'L1050X4XX140000'" />
					</xsl:call-template>
				</ns:LigneA>
			</ns:L1050X4XX140000>
		</ns:A050>
	</xsl:template>
</xsl:stylesheet>